@@ -108,7 +108,8 @@ gdaui_entry_common_time_get_type (void)
 			NULL,
 			sizeof (GdauiEntryCommonTime),
 			0,
-			(GInstanceInitFunc) gdaui_entry_common_time_init
+			(GInstanceInitFunc) gdaui_entry_common_time_init,
+			0
 		};
 
 		static const GInterfaceInfo cell_editable_info = {
@@ -153,7 +154,7 @@ gdaui_entry_common_time_class_init (GdauiEntryCommonTimeClass * class)
 }
 
 static gboolean
-key_press_event_cb (GdauiEntryCommonTime *mgtim, GdkEventKey *key_event, gpointer data)
+key_press_event_cb (GdauiEntryCommonTime *mgtim, GdkEventKey *key_event, G_GNUC_UNUSED gpointer data)
 {
 	if (key_event->keyval == GDK_Escape)
 		mgtim->priv->editing_canceled = TRUE;
@@ -482,7 +483,7 @@ focus_out_cb (GtkWidget *widget, GdkEventFocus *event, GdauiEntryCommonTime *mgt
 	g_assert (activate_cb);
 	((Callback2)activate_cb) (widget, mgtim);
 
-	return FALSE;
+	return gtk_widget_event (GTK_WIDGET (mgtim), (GdkEvent*) event);
 }
 
 static void
@@ -519,7 +520,7 @@ connect_signals (GdauiEntryWrapper *mgwrap, GCallback modify_cb, GCallback activ
 }
 
 static gboolean
-can_expand (GdauiEntryWrapper *mgwrap, gboolean horiz)
+can_expand (G_GNUC_UNUSED GdauiEntryWrapper *mgwrap, G_GNUC_UNUSED gboolean horiz)
 {
 	return FALSE;
 }
@@ -646,7 +647,8 @@ create_entry_date (GdauiEntryCommonTime *mgtim)
 }
 
 static void
-entry_date_insert_func (GdauiFormattedEntry *fentry, gunichar insert_char, gint virt_pos, gpointer data)
+entry_date_insert_func (G_GNUC_UNUSED GdauiFormattedEntry *fentry, gunichar insert_char,
+			G_GNUC_UNUSED gint virt_pos, gpointer data)
 {
 	GValue *value;
 	GType type;
@@ -725,7 +727,7 @@ entry_date_insert_func (GdauiFormattedEntry *fentry, gunichar insert_char, gint
 }
 
 static void
-internal_set_time (GtkWidget *widget, GdauiEntryCommonTime *mgtim)
+internal_set_time (G_GNUC_UNUSED GtkWidget *widget, GdauiEntryCommonTime *mgtim)
 {
 	/* the aim is that when the mode is TIMESTAMP, when the user sets a date,
 	 * then the time automatically sets to 00:00:00
@@ -760,7 +762,7 @@ hide_popup (GdauiEntryCommonTime *mgtim)
 }
 
 static gint
-date_delete_popup (GtkWidget *widget, GdauiEntryCommonTime *mgtim)
+date_delete_popup (G_GNUC_UNUSED GtkWidget *widget, GdauiEntryCommonTime *mgtim)
 {
 	hide_popup (mgtim);
 	return TRUE;
@@ -810,7 +812,7 @@ date_day_selected (GtkCalendar *calendar, GdauiEntryCommonTime *mgtim)
 {
 	char buffer [256];
         guint year, month, day;
-        struct tm mtm = {0};
+        struct tm mtm = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
         char *str_utf8;
 
         gtk_calendar_get_date (calendar, &year, &month, &day);
@@ -832,7 +834,7 @@ date_day_selected (GtkCalendar *calendar, GdauiEntryCommonTime *mgtim)
 }
 
 static void
-date_day_selected_double_click (GtkCalendar *calendar, GdauiEntryCommonTime *mgtim)
+date_day_selected_double_click (G_GNUC_UNUSED GtkCalendar *calendar, GdauiEntryCommonTime *mgtim)
 {
 	hide_popup (mgtim);
 }
@@ -1056,7 +1058,8 @@ create_entry_time (GdauiEntryCommonTime *mgtim)
 }
 
 static void
-entry_time_insert_func (GdauiFormattedEntry *fentry, gunichar insert_char, gint virt_pos, gpointer data)
+entry_time_insert_func (G_GNUC_UNUSED GdauiFormattedEntry *fentry, gunichar insert_char,
+			G_GNUC_UNUSED gint virt_pos, gpointer data)
 {
 	GValue *value;
 	GType type;
@@ -1122,13 +1125,13 @@ create_entry_ts (GdauiEntryCommonTime *mgtim)
  * GtkCellEditable interface
  */
 static void
-gtk_cell_editable_entry_editing_done_cb (GtkEntry *entry, GdauiEntryCommonTime *mgtim) 
+gtk_cell_editable_entry_editing_done_cb (G_GNUC_UNUSED GtkEntry *entry, GdauiEntryCommonTime *mgtim)
 {
 	gtk_cell_editable_editing_done (GTK_CELL_EDITABLE (mgtim));
 }
 
 static void
-gtk_cell_editable_entry_remove_widget_cb (GtkEntry *entry, GdauiEntryCommonTime *mgtim) 
+gtk_cell_editable_entry_remove_widget_cb (G_GNUC_UNUSED GtkEntry *entry, GdauiEntryCommonTime *mgtim)
 {
 	gtk_cell_editable_remove_widget (GTK_CELL_EDITABLE (mgtim));
 }
