@@ -53,9 +53,12 @@ GHashTable *gdaui_plugins_hash = NULL; /* key = plugin name, value = GdauiPlugin
  * Initialization of the libgda-ui library, must be called before any usage of the library.
  *
  * <itemizedlist>
- * <listitem><para>Note1: gtk_init() is not called by this function and should also
- *   be called (the calling order has no importance)</para></listitem>
- * <listitem><para>Note2: this funtion also calls gda_init() so it should not be called
+ * <listitem><para>Note 1: gtk_init() is not called by this function and should also
+ *   be called (see Note 2 about the importance of the calling order)</para></listitem>
+ * <listitem><para>Note 2: unless you call setlocale() first in your program, calling gtk_init()
+ *    before gdaui_init() will ensure that all information loaded from config files will
+ *    be loaded in the correct locale (as gtk_init() calls setlocale()).</para></listitem>
+ * <listitem><para>Note 3: this funtion also calls gda_init() so it should not be called
  *    again</para></listitem>
  * </itemizedlist>
  *
@@ -115,7 +118,7 @@ gdaui_new_data_entry (GType type, const gchar *plugin_name)
 	if (type == G_TYPE_INVALID)
 		return (GdauiDataEntry *) gdaui_entry_none_new (GDA_TYPE_NULL);
 
-	dh = gda_get_default_handler (type);
+	dh = gda_data_handler_get_default (type);
 
 	if (plugin_name && *plugin_name) {
 		GdauiPlugin *plugin_struct;
@@ -131,8 +134,20 @@ gdaui_new_data_entry (GType type, const gchar *plugin_name)
 		}
 		
 		plugin_struct = g_hash_table_lookup (gdaui_plugins_hash, plugin);
-		if (plugin_struct && plugin_struct->entry_create_func) 
-			entry = (plugin_struct->entry_create_func) (dh, type, options);
+		if (plugin_struct && plugin_struct->entry_create_func) { 
+			gboolean allok = TRUE;
+			if (plugin_struct->nb_g_types > 0) {
+				gint i;
+				for (i = 0; i < plugin_struct->nb_g_types; i++) {
+					if (plugin_struct->valid_g_types[i] == type)
+						break;
+				}
+				if (i == plugin_struct->nb_g_types)
+					allok = FALSE;
+			}
+			if (allok)
+				entry = (plugin_struct->entry_create_func) (dh, type, options);
+		}
 		g_free (plugin);
 	}
 
@@ -201,7 +216,7 @@ _gdaui_new_cell_renderer (GType type, const gchar *plugin_name)
 	if (!gdaui_plugins_hash) 
 		gdaui_plugins_hash = init_plugins_hash ();
 
-	dh = gda_get_default_handler (type);
+	dh = gda_data_handler_get_default (type);
 	
 	if (plugin_name && *plugin_name) {
 		GdauiPlugin *plugin_struct;
