@@ -1,6 +1,6 @@
 /* gdaui-rt-editor.c
  *
- * Copyright (C) 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -160,10 +160,9 @@ static const GtkToggleActionEntry ui_toggle_actions [] =
         { "ActionHelp", GTK_STOCK_HELP, N_("_Syntax help"), NULL, N_("Show syntax help"), G_CALLBACK (help_cb), FALSE}
 };
 
-/* STOCK_SELECT_COLOR */
 static const GtkActionEntry ui_actions[] = {
         { "ActionAddImage", "insert-image", N_("_Add image"), NULL, N_("Insert image"), G_CALLBACK (add_image_cb)},
-        { "ActionReset", GTK_STOCK_CLEAR, N_("_Reset"), NULL, N_("Reset to normal text"), G_CALLBACK (reset_all_cb)},
+        { "ActionReset", GTK_STOCK_CLEAR, N_("_Normal text"), NULL, N_("Reset to normal text"), G_CALLBACK (reset_all_cb)},
 };
 
 static const gchar *ui_actions_info =
@@ -361,6 +360,7 @@ gdaui_rt_editor_init (GdauiRtEditor *rte)
 
 	/* action group */
 	rte->priv->actions_group = gtk_action_group_new ("Actions");
+	gtk_action_group_set_translation_domain (rte->priv->actions_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_toggle_actions (rte->priv->actions_group, ui_toggle_actions,
 					     G_N_ELEMENTS (ui_toggle_actions), rte);
         gtk_action_group_add_actions (rte->priv->actions_group, ui_actions, G_N_ELEMENTS (ui_actions),
@@ -616,13 +616,13 @@ underline_cb (GtkToggleAction *action, GdauiRtEditor *rte)
 }
 
 static void
-reset_all_cb (GtkAction *action, GdauiRtEditor *rte)
+reset_all_cb (G_GNUC_UNUSED GtkAction *action, GdauiRtEditor *rte)
 {
 	apply_tag (rte, FALSE, NULL);
 }
 
 static void
-add_image_cb (GtkAction *action, GdauiRtEditor *rte)
+add_image_cb (G_GNUC_UNUSED GtkAction *action, GdauiRtEditor *rte)
 {
 	GtkWidget *dlg;
         GtkFileFilter *filter;
@@ -708,7 +708,7 @@ mark_set_cb (GtkTextBuffer *textbuffer, GtkTextIter *location, GtkTextMark *mark
 }
 
 static void
-insert_text_cb (GtkTextBuffer *textbuffer, GtkTextIter *location, gchar *text, gint len, GdauiRtEditor *rte)
+insert_text_cb (GtkTextBuffer *textbuffer, GtkTextIter *location, G_GNUC_UNUSED gchar *text, G_GNUC_UNUSED gint len, GdauiRtEditor *rte)
 {
 	/* if inserting is before a bullet, then insert right after */
 	GtkTextTag *tag;
@@ -721,7 +721,7 @@ insert_text_cb (GtkTextBuffer *textbuffer, GtkTextIter *location, gchar *text, g
 }
 
 static void
-insert_text_after_cb (GtkTextBuffer *textbuffer, GtkTextIter *location, gchar *text, gint len, GdauiRtEditor *rte)
+insert_text_after_cb (GtkTextBuffer *textbuffer, GtkTextIter *location, gchar *text, G_GNUC_UNUSED gint len, GdauiRtEditor *rte)
 {
 	GtkTextIter start, end;
 
@@ -788,7 +788,8 @@ show_markup_item_activate_cb (GtkCheckMenuItem *checkmenuitem, GdauiRtEditor *rt
 }
 
 static void
-bigger_font_item_activate_cb (GtkCheckMenuItem *checkmenuitem, GdauiRtEditor *rte)
+bigger_font_item_activate_cb (G_GNUC_UNUSED GtkCheckMenuItem *checkmenuitem,
+			      GdauiRtEditor *rte)
 {
 	PangoContext *pcontext;
 	PangoFontDescription *fd, *nfd;
@@ -801,7 +802,8 @@ bigger_font_item_activate_cb (GtkCheckMenuItem *checkmenuitem, GdauiRtEditor *rt
 }
 
 static void
-smaller_font_item_activate_cb (GtkCheckMenuItem *checkmenuitem, GdauiRtEditor *rte)
+smaller_font_item_activate_cb (G_GNUC_UNUSED GtkCheckMenuItem *checkmenuitem,
+			       GdauiRtEditor *rte)
 {
 	PangoContext *pcontext;
 	PangoFontDescription *fd, *nfd;
@@ -814,13 +816,14 @@ smaller_font_item_activate_cb (GtkCheckMenuItem *checkmenuitem, GdauiRtEditor *r
 }
 
 static void
-reset_font_item_activate_cb (GtkCheckMenuItem *checkmenuitem, GdauiRtEditor *rte)
+reset_font_item_activate_cb (G_GNUC_UNUSED GtkCheckMenuItem *checkmenuitem,
+			     GdauiRtEditor *rte)
 {
 	gtk_widget_modify_font (GTK_WIDGET (rte->priv->textview), NULL);
 }
 
 static void
-populate_popup_cb (GtkTextView *entry, GtkMenu *menu, GdauiRtEditor *rte)
+populate_popup_cb (G_GNUC_UNUSED GtkTextView *entry, GtkMenu *menu, GdauiRtEditor *rte)
 {
 	GtkWidget *item;
 
@@ -1611,7 +1614,8 @@ remove_newlines_from_base64 (gchar *base64)
 }
 
 static void
-serialize_text (GtkTextBuffer *buffer, SerializationContext *context, GdauiRtEditor *editor)
+serialize_text (G_GNUC_UNUSED GtkTextBuffer *buffer, SerializationContext *context,
+		GdauiRtEditor *editor)
 {
 	GtkTextIter iter, old_iter;
 	GList *opened_tags = NULL; /* 1st element of the list is the last opened tag (ie. the one
@@ -1785,7 +1789,7 @@ serialize_text (GtkTextBuffer *buffer, SerializationContext *context, GdauiRtEdi
  * serialize_as_txt2tag:
  */
 static guint8 *
-serialize_as_txt2tag (GtkTextBuffer     *register_buffer,
+serialize_as_txt2tag (G_GNUC_UNUSED  GtkTextBuffer *register_buffer,
 		      GtkTextBuffer     *content_buffer,
 		      const GtkTextIter *start,
 		      const GtkTextIter *end,
