@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2009 Vivien Malerba
+ * Copyright (C) 2009 - 2011 Vivien Malerba
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -24,6 +24,7 @@
 #include "support.h"
 #include "marshal.h"
 #include <libgda/gda-sql-builder.h>
+#include <sql-parser/gda-sql-parser.h>
 
 struct _BrowserFavoritesPrivate {
 	GdaMetaStore  *store;
@@ -212,6 +213,8 @@ favorite_type_to_string (BrowserFavoritesType type)
 		return "QUERY";
 	case BROWSER_FAVORITES_DATA_MANAGERS:
 		return "DATAMAN";
+	case BROWSER_FAVORITES_ACTIONS:
+		return "ACTION";
 	default:
 		g_warning ("Unknown type of favorite");
 	}
@@ -232,6 +235,8 @@ favorite_string_to_type (const gchar *str)
 	}
 	else if (*str == 'Q')
 		return BROWSER_FAVORITES_QUERIES;
+	else if (*str == 'A')
+		return BROWSER_FAVORITES_ACTIONS;
 	else
 		g_warning ("Unknown type '%s' of favorite", str);
 	return 0;
@@ -485,6 +490,12 @@ favorites_reorder (BrowserFavorites *bfav, gint order_key, gint id, gint new_pos
 
 /**
  * browser_favorites_add
+ * @bfav: a #BrowserFavorites object
+ * @session_id: session ID (0)
+ * @fav: a pointer to a #BrowserFavoritesAttributes structure
+ * @order_key: ordering key or -1 for none
+ * @pos: position (ignored if @order_key < 0)
+ * @error: a place to store errors, or %NULL
  *
  * Add a new favorite, or replace an existing one.
  * NOTE:
@@ -924,10 +935,10 @@ browser_favorites_list (BrowserFavorites *bfav, guint session_id, BrowserFavorit
 
 
 /**
- * browser_favorites_delete_favorite
+ * browser_favorites_delete
  * @bfav: a #BrowserFavorites
  * @session_id: 0 for now
- * @fav: a pointer to a #BrowserFavoritesAttributes definting which favorite to delete
+ * @fav: a pointer to a #BrowserFavoritesAttributes definning which favorite to delete
  * @error: a place to store errors, or %NULL
  *
  * Delete a favorite
@@ -1140,3 +1151,154 @@ browser_favorites_get (BrowserFavorites *bfav, gint fav_id,
 	g_object_unref (G_OBJECT (model));
 	return retval;
 }
+
+static gint
+actions_sort_func (BrowserFavoriteAction *act1, BrowserFavoriteAction *act2)
+{
+	return act2->nb_bound - act1->nb_bound;
+}
+
+/**
+ * browser_favorites_get_actions
+ * @bfav: a #BrowserFavorites
+ * @bcnc: a #BrowserConnection
+ * @set: a #GdaSet
+ *
+ * Get a list of #BrowserFavoriteAction which can be executed with the data in @set.
+ *
+ * Returns: a new list of #BrowserFavoriteAction, free list with browser_favorites_free_actions()
+ */
+GSList *
+browser_favorites_get_actions (BrowserFavorites *bfav, BrowserConnection *bcnc, GdaSet *set)
+{
+	GSList *fav_list, *list, *retlist = NULL;
+	g_return_val_if_fail (BROWSER_IS_FAVORITES (bfav), NULL);
+	g_return_val_if_fail (BROWSER_IS_CONNECTION (bcnc), NULL);
+	g_return_val_if_fail (!set || GDA_IS_SET (set), NULL);
+
+	fav_list = browser_favorites_list (bfav, 0, BROWSER_FAVORITES_ACTIONS, -1, NULL);
+	if (! fav_list)
+		return NULL;
+
+	for (list = fav_list; list; list = list->next) {
+		BrowserFavoritesAttributes *fa = (BrowserFavoritesAttributes*) list->data;
+		BrowserFavoritesAttributes qfa;
+		if (! g_str_has_prefix (fa->contents, "QUERY")) {
+			g_warning ("Malformed action contents '%s', please report error to "
+				   "http://bugzilla.gnome.org/ for the \"libgda\" product",
+				   fa->contents);
+			continue;
+		}
+		if (browser_favorites_get (bfav, atoi (fa->contents + 5), &qfa, NULL)) {
+			GdaSet *params;
+			GSList *plist;
+			GdaBatch *batch;
+			GdaStatement *stmt = NULL;
+			GdaSqlParser *parser;
+			const gchar *remain;
+			const GSList *stmt_list;
+			gint nb_bound = 0;
+
+			parser = browser_connection_create_parser (bcnc);
+			batch = gda_sql_parser_parse_string_as_batch (parser, qfa.contents, &remain, NULL);
+			g_object_unref (parser);
+			if (!batch) {
+				browser_favorites_reset_attributes (&qfa);
+				continue;
+			}
+			stmt_list = gda_batch_get_statements (batch);
+			for (plist = (GSList*) stmt_list; plist; plist = plist->next) {
+				if (! gda_statement_is_useless (GDA_STATEMENT (plist->data))) {
+					if (stmt)
+						break;
+					else
+						stmt = g_object_ref (GDA_STATEMENT (plist->data));
+				}
+			}
+			g_object_unref (batch);
+			if (!stmt || plist) {
+				browser_favorites_reset_attributes (&qfa);
+				continue;
+			}
+			
+			if (! gda_statement_get_parameters (stmt, &params, NULL) || !params) {
+				g_object_unref (stmt);
+				browser_favorites_reset_attributes (&qfa);
+				continue;
+			}
+			browser_connection_define_ui_plugins_for_stmt (bcnc, stmt, params);
+			
+			for (plist = params->holders; plist; plist = plist->next) {
+				/* try to find holder in @set */
+				GdaHolder *req_holder, *in_holder;
+				req_holder = GDA_HOLDER (plist->data);
+				in_holder = gda_set_get_holder (set, gda_holder_get_id (req_holder));
+				if (in_holder && gda_holder_set_bind (req_holder, in_holder, NULL)) {
+					/* bound this holder to the oune found */
+					nb_bound++;
+				}
+			}
+
+			if (nb_bound > 0) {
+				/* at least 1 holder was found=> keep the action */
+				BrowserFavoriteAction *act;
+				act = g_new0 (BrowserFavoriteAction, 1);
+				retlist = g_slist_insert_sorted (retlist, act,
+								 (GCompareFunc) actions_sort_func);
+				act->params = g_object_ref (params);
+				act->id = fa->id;
+				act->name = g_strdup (fa->name);
+				act->stmt = g_object_ref (stmt);
+				act->nb_bound = nb_bound;
+
+				/*g_print ("Action identified: ID=%d Bound=%d name=[%s] SQL=[%s]\n",
+				  act->id, act->nb_bound,
+				  act->name, qfa.contents);*/
+			}
+
+			g_object_unref (stmt);
+			g_object_unref (params);
+			browser_favorites_reset_attributes (&qfa);
+		}
+	}
+	browser_favorites_free_list (fav_list);
+
+	return retlist;
+}
+
+/**
+ * browser_favorites_free_action
+ * @action: a #BrowserFavoriteAction, or %NULL
+ *
+ * Frees @action
+ */
+void
+browser_favorites_free_action (BrowserFavoriteAction *action)
+{
+	if (! action)
+		return;
+	g_free (action->name);
+	if (action->stmt)
+		g_object_unref (action->stmt);
+	if (action->params)
+		g_object_unref (action->params);
+	g_free (action);
+}
+
+/**
+ * browser_favorites_free_actions_list
+ * @actions_list: a list of #BrowserFavoriteAction, or %NULL
+ *
+ * Free a list of #BrowserFavoriteAction (frees the list and each #BrowserFavoriteAction)
+ */
+void
+browser_favorites_free_actions_list (GSList *actions_list)
+{
+	GSList *list;
+	if (!actions_list)
+		return;
+
+	for (list = actions_list; list; list = list->next)
+		browser_favorites_free_action ((BrowserFavoriteAction*) list->data);
+	g_slist_free (actions_list);
+}
