@@ -75,7 +75,8 @@ data_source_manager_get_type (void)
 			NULL,
 			sizeof (DataSourceManager),
 			0,
-			(GInstanceInitFunc) data_source_manager_init
+			(GInstanceInitFunc) data_source_manager_init,
+			0
 		};
 
 		
@@ -493,7 +494,7 @@ data_source_manager_get_params (DataSourceManager *mgr)
  * Returns: an array of arrays of pointer to the #DataSource objects
  */
 GArray *
-data_source_manager_get_sources_array (DataSourceManager *mgr, GError **error)
+data_source_manager_get_sources_array (DataSourceManager *mgr, G_GNUC_UNUSED GError **error)
 {
 	g_return_val_if_fail (IS_DATA_SOURCE_MANAGER (mgr), NULL);
 
@@ -529,11 +530,11 @@ data_source_manager_get_sources_array (DataSourceManager *mgr, GError **error)
 		}
 		
 		if (array) {
-			gint i;
+			gssize i;
 			gboolean dep_found = FALSE;
 			for (i = array->len - 1; i >= 0 ; i--) {
 				GArray *subarray = g_array_index (array, GArray*, i);
-				gint j;
+				gsize j;
 				for (j = 0; j < subarray->len; j++) {
 					DataSource *source2 = g_array_index (subarray, DataSource*, j);
 					if (source_depends_on (source, source2)) {
@@ -546,7 +547,7 @@ data_source_manager_get_sources_array (DataSourceManager *mgr, GError **error)
 							g_array_append_val (subarray, source);
 						}
 						else {
-							gint k;
+							gsize k;
 							GArray *subarray = g_array_index (array, GArray*, i+1);
 							for (k = 0; k < subarray->len; k++) {
 								DataSource *source3 = g_array_index (subarray,
@@ -604,12 +605,12 @@ data_source_manager_get_sources_array (DataSourceManager *mgr, GError **error)
 void
 data_source_manager_destroy_sources_array (GArray *array)
 {
-	gint i;
+	gsize i;
 	g_return_if_fail (array);
 	for (i = 0; i < array->len; i++) {
 		GArray *subarray;
 		subarray = g_array_index (array, GArray *, i);
-		gint j;
+		gsize j;
 		for (j = 0; j < subarray->len; j++) {
 			DataSource *source;
 			source = g_array_index (subarray, DataSource *, j);
